@@ -30,10 +30,10 @@ simple_colours = [
 def pylab_context_ioff():
     """A way of turning off pylab's interactive mode with a 'with' statement. For example
     you could do:
-    
+
         with pylab_context_ioff():
         ... pylab.figure()
-    
+
     to ensure the figure was created in non-interactive mode. After the context has ended,
     pylab's interactive status is returned to what it was before the context was entered.
     """
@@ -64,14 +64,14 @@ def pylab_ioff(fn):
             if interactive_mode:
                 #logging.debug('Turning pylab interactive on.')
                 P.ion()
-    
+
     return wrapper
 
 
 def set_rcParams_for_latex(fig_width_pt=None):
     """
     Set the rcParams in matplotlib to use postscript output.
-    
+
     If fig_width_pt is given then set default figure size to match.
     """
     params = {
@@ -79,7 +79,7 @@ def set_rcParams_for_latex(fig_width_pt=None):
         'text.usetex'     : True,
     }
     P.rcParams.update(params)
-    
+
     if None != fig_width_pt:
         P.rcParams['figure.figsize'] = get_fig_size_for_latex(fig_width_pt)
 
@@ -87,7 +87,7 @@ def set_rcParams_for_latex(fig_width_pt=None):
 def get_fig_size_for_latex(fig_width_pt=345.):
     """
     Get fig_width_pt from LaTeX using \showthe\columnwidth
-    
+
     @return: figure size tuple if fig_width_pt was specified
     """
     inches_per_pt = 1.0/72.27                 # Convert pt to inch
@@ -104,7 +104,7 @@ def _choose_other_dim(num_sub_plots, dim):
 
 def layout_sub_plot(num_sub_plots, num_rows=0, num_cols=0):
     "Specify either num_rows or num_cols."
-    
+
     # make sure are positive
     if num_rows < 0:
         raise ValueError('num_rows must be positive.')
@@ -117,7 +117,7 @@ def layout_sub_plot(num_sub_plots, num_rows=0, num_cols=0):
             raise ValueError('Specified both num_rows and num_cols but could have used fewer num_rows.')
         if (num_cols-1) * num_rows >= num_sub_plots:
             raise ValueError('Specified both num_rows and num_cols but could have used fewer num_cols.')
-    
+
     # is num_rows specified?
     elif num_rows:
         num_cols = _choose_other_dim(num_sub_plots, num_rows)
@@ -125,14 +125,14 @@ def layout_sub_plot(num_sub_plots, num_rows=0, num_cols=0):
     # is num_cols specified?
     elif num_cols:
         num_rows = _choose_other_dim(num_sub_plots, num_cols)
-        
+
     # make as square as possible
     else:
         num_rows = int(math.sqrt(num_sub_plots))
         num_cols = _choose_other_dim(num_sub_plots, num_rows)
-    
+
     return num_rows, num_cols
-        
+
 
 
 
@@ -159,7 +159,7 @@ def violin_plot(ax, data, pos, bp=False, facecolor='y', alpha=0.3):
 
 def create_format_cycler(**formats):
     """Cycle through various format strings so that many different data can be displayed together.
-    
+
     If specifying many formats it is best to make them relatively prime to ensure the largest total cycle length.
     """
     def get_format_str(i):
@@ -172,14 +172,14 @@ def create_format_cycler(**formats):
 #
 # Create a format cycler
 #
-all_line_styles = ('-', '--', '-.', '.')
+all_line_styles = ('-', '--', '-.')
 simple_marker_styles = 'vos*D'
 
 
 
 
 if '__main__' == __name__:
-    
+
     class TestPylabIOff(object):
         @pylab_ioff
         def some_method(self, title, data):
@@ -203,7 +203,7 @@ if '__main__' == __name__:
 
     logging.basicConfig(level=logging.DEBUG)
     _logger.setLevel(logging.DEBUG)
-    
+
     P.ion()
 
     test = TestPylabIOff()
